\name{rpuScale}
\alias{rpuScale}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Scaling SVM Training Data}
\description{
  The \code{rpuScale} method performs scaling on SVM training data.
  It is not supported in the free \code{rpud} package.
}
\usage{
rpuScale(x, y=NULL, scale=TRUE)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{x}{a data matrix, a vector, or a sparse matrix (object of class
    \code{\link[Matrix]{Matrix}} provided by the \pkg{Matrix} package,
    or of class \code{\link[SparseM]{matrix.csr}}
    provided by the \pkg{SparseM} package.}
  \item{y}{a response vector with one label for each row/component of
    \code{x}. Can be either a factor (for classification tasks)
    or a numeric vector (for regression).}
  \item{scale}{It can be a numeric vector or a single logical value.
    If it is a numeric vector, the first and second vector elements 
    will be the lower and upper bounds 
    of each attributes in the \code{x} component after scaling.
    The third and fourth optional vector elements will be the 
    lower and upper bounds of the \code{y} component after scaling.
    This is ignored if \code{y} is of factor type.
    If \code{scale} is a single logical \code{TRUE} value, 
    the default scale vector \code{c(0, 1, -1, 1)} will be applied.}
}
\value{
  \code{rpuScale} returns a list with components:
  \item{x}{a scaled version of the \code{x} input.}
  \item{y}{a scaled version of the \code{y} input.}
  \item{x.scale}{The lower and upper bounds of the attributes in the scaled \code{x}.}
  \item{y.scale}{The lower and upper bounds of the scaled vector \code{y}.}
  \item{x.bound}{The lower and upper bounds of the attributes in the original \code{x} input matrix.}
  \item{y.bound}{The lower and upper bounds of the original \code{y} input vector.}
  \item{r2}{Scaling factor for the mean square error.}
}
\author{
  Chi Yau (based on \code{svm} in \code{e1071} by David Meyer)\cr
  \email{chi.yau@r-tutor.com}
}
\seealso{\code{\link[SparseM]{matrix.csr}}}

\examples{
\dontrun{

library(rpud)
library(SparseM)

cadata1.path <- file.path(.path.package(package="rpud"), "runit/data/cadata-sample")
cadata1.data <- read.svm.data(cadata1.path, fac=FALSE)
cadata1.rpusvm <- rpusvm(cadata1.data$x, cadata1.data$y, type=type)
cadata1.fitted <- fitted(cadata1.rpusvm)

cadata1.scaled <- rpuScale(cadata1.data$x, cadata1.data$y)
cadata2.rpusvm <- rpusvm(cadata1.scaled$x, cadata1.scaled$y, type=type, scale=FALSE)
cadata2.fitted <- fitted(cadata2.rpusvm)

cadata1.yrange <- cadata1.scaled$y.bound[2]-cadata1.scaled$y.bound[1]
cadata1.yscale <- cadata1.scaled$y.scale[2]-cadata1.scaled$y.scale[1]

cadata2.fitted.scaled <-
        (cadata2.fitted - cadata1.scaled$y.scale[1])*cadata1.yrange/cadata1.yscale +
        cadata1.scaled$y.bound[1]
all.equal(cadata1.fitted, cadata2.fitted.scaled, tol=50)


}}
\keyword{IO}% at least one, from doc/KEYWORDS
